@@ -62,7 +62,15 @@ class SettingsParser(argparse.ArgumentParser):
 
         return super(SettingsParser, self).add_argument(name, *args, **kwargs)
 
-    def parse_args(self, *args, **kwargs):
+    def add_setting(self, name, default=None):
+        """
+        Add a setting option that can only be provided by config file.  Useful
+        for lists and dicts that can't be cleanly supplied in an env var or
+        command line arg.
+        """
+        self.yaml_settings.setdefault(name, default)
+
+    def _get_settings_namespace(self):
         # the superclass's parse_args allows you to pass your own namespace
         # object, which it well then update.  We can take advantage of that by
         # creating one of our own, populating it with env/yaml values, then
@@ -79,6 +87,12 @@ class SettingsParser(argparse.ArgumentParser):
                 val = params['type'](os.environ[params['evname']])
                 setattr(namespace, setting, val)
 
-        kwargs['namespace'] = namespace
+        return namespace
 
+    def parse_args(self, *args, **kwargs):
+        kwargs['namespace'] = self._get_settings_namespace()
         return super(SettingsParser, self).parse_args(*args, **kwargs)
+
+    def parse_known_args(self, *args, **kwargs):
+        kwargs['namespace'] = self._get_settings_namespace()
+        return super(SettingsParser, self).parse_known_args(*args, **kwargs)
